pm4py.statistics.passed\_time.pandas package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.passed_time.pandas.variants

Submodules
----------

pm4py.statistics.passed\_time.pandas.algorithm module
-----------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.pandas.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.passed_time.pandas
   :members:
   :undoc-members:
   :show-inheritance:
